@@ -41,12 +41,6 @@
 #include "config.h"
 #endif
 
-/* FIXME 0.11: suppress warnings for deprecated API such as GStaticRecMutex
- * with newer GLib versions (>= 2.31.0) */
-#define GLIB_DISABLE_DEPRECATION_WARNINGS
-
-#include <gst/glib-compat-private.h>
-
 #include "gstimagefreeze.h"
 
 static void gst_image_freeze_finalize (GObject * object);
@@ -95,10 +89,10 @@ gst_image_freeze_base_init (gpointer g_class)
       "Generates a still frame stream from an image",
       "Sebastian Dröge <sebastian.droege@collabora.co.uk>");
 
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &sink_pad_template);
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &src_pad_template);
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&sink_pad_template));
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&src_pad_template));
 }
 
 static void
@@ -399,7 +393,6 @@ gst_image_freeze_convert (GstImageFreeze * self,
         default:
           break;
       }
-      break;
     }
     case GST_FORMAT_TIME:{
       switch (*dest_format) {
@@ -414,7 +407,7 @@ gst_image_freeze_convert (GstImageFreeze * self,
         default:
           break;
       }
-      break;
+
     }
     default:
       break;
@@ -472,14 +465,12 @@ gst_image_freeze_src_query (GstPad * pad, GstQuery * query)
           position = self->offset;
           g_mutex_unlock (self->lock);
           ret = TRUE;
-          break;
         }
         case GST_FORMAT_TIME:{
           g_mutex_lock (self->lock);
           position = self->segment.last_stop;
           g_mutex_unlock (self->lock);
           ret = TRUE;
-          break;
         }
         default:
           break;
@@ -506,7 +497,6 @@ gst_image_freeze_src_query (GstPad * pad, GstQuery * query)
           duration = self->segment.stop;
           g_mutex_unlock (self->lock);
           ret = TRUE;
-          break;
         }
         case GST_FORMAT_DEFAULT:{
           g_mutex_lock (self->lock);
@@ -517,7 +507,6 @@ gst_image_freeze_src_query (GstPad * pad, GstQuery * query)
                 GST_SECOND * self->fps_d);
           g_mutex_unlock (self->lock);
           ret = TRUE;
-          break;
         }
         default:
           break;
@@ -755,7 +744,7 @@ gst_image_freeze_src_loop (GstPad * pad)
   GstImageFreeze *self = GST_IMAGE_FREEZE (GST_PAD_PARENT (pad));
   GstBuffer *buffer;
   guint64 offset;
-  GstClockTime timestamp, timestamp_end;
+  GstClockTime timestamp, timestamp_end, duration;
   gint64 cstart, cstop;
   gboolean in_seg, eos;
 
@@ -811,9 +800,11 @@ gst_image_freeze_src_loop (GstPad * pad)
     timestamp_end =
         gst_util_uint64_scale (offset + 1, self->fps_d * GST_SECOND,
         self->fps_n);
+    duration = timestamp_end - timestamp;
   } else {
     timestamp = self->segment.start;
     timestamp_end = GST_CLOCK_TIME_NONE;
+    duration = GST_CLOCK_TIME_NONE;
   }
 
   eos = (self->fps_n == 0 && offset > 0) ||
