@@ -54,8 +54,8 @@ struct _GstRtpH264Depay
   gboolean    merge;
   GstAdapter *picture_adapter;
   gboolean    picture_start;
-  gboolean    picture_complete;
   GstClockTime last_ts;
+  gboolean    last_keyframe;
 };
 
 struct _GstRtpH264DepayClass
