@@ -77,7 +77,7 @@ GST_BOILERPLATE (GstRtpMP4APay, gst_rtp_mp4a_pay, GstBaseRTPPayload,
       gst_static_pad_template_get (&gst_rtp_mp4a_pay_sink_template));
 
   gst_element_class_set_details_simple (element_class,
-      "RTP MPEG4 audio payloader", "Codec/Payloader/Network",
+      "RTP MPEG4 audio payloader", "Codec/Payloader/Network/RTP",
       "Payload MPEG4 audio as RTP packets (RFC 3016)",
       "Wim Taymans <wim.taymans@gmail.com>");
 }
@@ -433,5 +433,5 @@ gboolean
 gst_rtp_mp4a_pay_plugin_init (GstPlugin * plugin)
 {
   return gst_element_register (plugin, "rtpmp4apay",
-      GST_RANK_NONE, GST_TYPE_RTP_MP4A_PAY);
+      GST_RANK_SECONDARY, GST_TYPE_RTP_MP4A_PAY);
 }
