@@ -30,13 +30,6 @@
 GST_DEBUG_CATEGORY_STATIC (rtpspeexpay_debug);
 #define GST_CAT_DEFAULT (rtpspeexpay_debug)
 
-/* elementfactory information */
-static const GstElementDetails gst_rtp_speex_pay_details =
-GST_ELEMENT_DETAILS ("RTP Speex payloader",
-    "Codec/Payloader/Network",
-    "Payload-encodes Speex audio into a RTP packet",
-    "Edgard Lima <edgard.lima@indt.org.br>");
-
 static GstStaticPadTemplate gst_rtp_speex_pay_sink_template =
 GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
@@ -79,7 +72,10 @@ gst_rtp_speex_pay_base_init (gpointer klass)
       gst_static_pad_template_get (&gst_rtp_speex_pay_sink_template));
   gst_element_class_add_pad_template (element_class,
       gst_static_pad_template_get (&gst_rtp_speex_pay_src_template));
-  gst_element_class_set_details (element_class, &gst_rtp_speex_pay_details);
+  gst_element_class_set_details_simple (element_class, "RTP Speex payloader",
+      "Codec/Payloader/Network/RTP",
+      "Payload-encodes Speex audio into a RTP packet",
+      "Edgard Lima <edgard.lima@indt.org.br>");
 
   GST_DEBUG_CATEGORY_INIT (rtpspeexpay_debug, "rtpspeexpay", 0,
       "Speex RTP Payloader");
@@ -88,11 +84,9 @@ gst_rtp_speex_pay_base_init (gpointer klass)
 static void
 gst_rtp_speex_pay_class_init (GstRtpSPEEXPayClass * klass)
 {
-  GObjectClass *gobject_class;
   GstElementClass *gstelement_class;
   GstBaseRTPPayloadClass *gstbasertppayload_class;
 
-  gobject_class = (GObjectClass *) klass;
   gstelement_class = (GstElementClass *) klass;
   gstbasertppayload_class = (GstBaseRTPPayloadClass *) klass;
 
@@ -286,11 +280,11 @@ gst_rtp_speex_pay_handle_buffer (GstBaseRTPPayload * basepayload,
   /* copy data in payload */
   memcpy (&payload[0], data, size);
 
-  gst_buffer_unref (buffer);
-
   ret = gst_basertppayload_push (basepayload, outbuf);
 
 done:
+  gst_buffer_unref (buffer);
+
   rtpspeexpay->packet++;
 
   return ret;
@@ -300,6 +294,7 @@ parse_error:
   {
     GST_ELEMENT_ERROR (rtpspeexpay, STREAM, DECODE, (NULL),
         ("Error parsing first identification packet."));
+    gst_buffer_unref (buffer);
     return GST_FLOW_ERROR;
   }
 }
@@ -337,5 +332,5 @@ gboolean
 gst_rtp_speex_pay_plugin_init (GstPlugin * plugin)
 {
   return gst_element_register (plugin, "rtpspeexpay",
-      GST_RANK_NONE, GST_TYPE_RTP_SPEEX_PAY);
+      GST_RANK_SECONDARY, GST_TYPE_RTP_SPEEX_PAY);
 }
