@@ -41,9 +41,9 @@ GST_DEBUG_CATEGORY_STATIC (gst_videomixer_blend_debug);
 /* Below are the implementations of everything */
 
 /* A32 is for AYUV, ARGB and BGRA */
-#define BLEND_A32(name, method, LOOP)		\
+#define BLEND_A32(name, LOOP) \
 static void \
-method##_ ##name (const guint8 * src, gint xpos, gint ypos, \
+blend_##name (const guint8 * src, gint xpos, gint ypos, \
     gint src_width, gint src_height, gdouble src_alpha, \
     guint8 * dest, gint dest_width, gint dest_height) \
 { \
@@ -83,31 +83,25 @@ method##_ ##name (const guint8 * src, gint xpos, gint ypos, \
   LOOP (dest, src, src_height, src_width, src_stride, dest_stride, s_alpha); \
 }
 
-#define BLEND_A32_LOOP(name, method)			\
+#define BLEND_A32_LOOP(name) \
 static inline void \
-_##method##_loop_##name (guint8 * dest, const guint8 * src, gint src_height, \
+_blend_loop_##name (guint8 * dest, const guint8 * src, gint src_height, \
     gint src_width, gint src_stride, gint dest_stride, guint s_alpha) \
 { \
   s_alpha = MIN (255, s_alpha); \
-  orc_##method##_##name (dest, dest_stride, src, src_stride, \
+  orc_blend_##name (dest, dest_stride, src, src_stride, \
       s_alpha, src_width, src_height); \
 }
 
-BLEND_A32_LOOP (argb, blend);
-BLEND_A32_LOOP (bgra, blend);
-BLEND_A32_LOOP (argb, overlay);
-BLEND_A32_LOOP (bgra, overlay);
+BLEND_A32_LOOP (argb);
+BLEND_A32_LOOP (bgra);
 
 #if G_BYTE_ORDER == LITTLE_ENDIAN
-BLEND_A32 (argb, blend, _blend_loop_argb);
-BLEND_A32 (bgra, blend, _blend_loop_bgra);
-BLEND_A32 (argb, overlay, _overlay_loop_argb);
-BLEND_A32 (bgra, overlay, _overlay_loop_bgra);
+BLEND_A32 (argb, _blend_loop_argb);
+BLEND_A32 (bgra, _blend_loop_bgra);
 #else
-BLEND_A32 (argb, blend, _blend_loop_bgra);
-BLEND_A32 (bgra, blend, _blend_loop_argb);
-BLEND_A32 (argb, overlay, _overlay_loop_bgra);
-BLEND_A32 (bgra, overlay, _overlay_loop_argb);
+BLEND_A32 (argb, _blend_loop_bgra);
+BLEND_A32 (bgra, _blend_loop_argb);
 #endif
 
 #define A32_CHECKER_C(name, RGB, A, C1, C2, C3) \
@@ -221,8 +215,8 @@ blend_##format_name (const guint8 * src, gint xpos, gint ypos, \
   gint xoffset = 0; \
   gint yoffset = 0; \
   gint src_comp_rowstride, dest_comp_rowstride; \
-  gint src_comp_height; \
-  gint src_comp_width; \
+  gint src_comp_height, dest_comp_height; \
+  gint src_comp_width, dest_comp_width; \
   gint comp_ypos, comp_xpos; \
   gint comp_yoffset, comp_xoffset; \
   \
@@ -262,7 +256,9 @@ blend_##format_name (const guint8 * src, gint xpos, gint ypos, \
   src_comp_rowstride = gst_video_format_get_row_stride (format_enum, 0, src_width); \
   dest_comp_rowstride = gst_video_format_get_row_stride (format_enum, 0, dest_width); \
   src_comp_height = gst_video_format_get_component_height (format_enum, 0, b_src_height); \
+  dest_comp_height = gst_video_format_get_component_height (format_enum, 0, dest_height); \
   src_comp_width = gst_video_format_get_component_width (format_enum, 0, b_src_width); \
+  dest_comp_width = gst_video_format_get_component_width (format_enum, 0, dest_width); \
   comp_xpos = (xpos == 0) ? 0 : gst_video_format_get_component_width (format_enum, 0, xpos); \
   comp_ypos = (ypos == 0) ? 0 : gst_video_format_get_component_height (format_enum, 0, ypos); \
   comp_xoffset = (xoffset == 0) ? 0 : gst_video_format_get_component_width (format_enum, 0, xoffset); \
@@ -278,7 +274,9 @@ blend_##format_name (const guint8 * src, gint xpos, gint ypos, \
   src_comp_rowstride = gst_video_format_get_row_stride (format_enum, 1, src_width); \
   dest_comp_rowstride = gst_video_format_get_row_stride (format_enum, 1, dest_width); \
   src_comp_height = gst_video_format_get_component_height (format_enum, 1, b_src_height); \
+  dest_comp_height = gst_video_format_get_component_height (format_enum, 1, dest_height); \
   src_comp_width = gst_video_format_get_component_width (format_enum, 1, b_src_width); \
+  dest_comp_width = gst_video_format_get_component_width (format_enum, 1, dest_width); \
   comp_xpos = (xpos == 0) ? 0 : gst_video_format_get_component_width (format_enum, 1, xpos); \
   comp_ypos = (ypos == 0) ? 0 : gst_video_format_get_component_height (format_enum, 1, ypos); \
   comp_xoffset = (xoffset == 0) ? 0 : gst_video_format_get_component_width (format_enum, 1, xoffset); \
@@ -294,7 +292,9 @@ blend_##format_name (const guint8 * src, gint xpos, gint ypos, \
   src_comp_rowstride = gst_video_format_get_row_stride (format_enum, 2, src_width); \
   dest_comp_rowstride = gst_video_format_get_row_stride (format_enum, 2, dest_width); \
   src_comp_height = gst_video_format_get_component_height (format_enum, 2, b_src_height); \
+  dest_comp_height = gst_video_format_get_component_height (format_enum, 2, dest_height); \
   src_comp_width = gst_video_format_get_component_width (format_enum, 2, b_src_width); \
+  dest_comp_width = gst_video_format_get_component_width (format_enum, 2, dest_width); \
   comp_xpos = (xpos == 0) ? 0 : gst_video_format_get_component_width (format_enum, 2, xpos); \
   comp_ypos = (ypos == 0) ? 0 : gst_video_format_get_component_height (format_enum, 2, ypos); \
   comp_xoffset = (xoffset == 0) ? 0 : gst_video_format_get_component_width (format_enum, 2, xoffset); \
@@ -666,8 +666,6 @@ PACKED_422_FILL_COLOR (uyvy, 16, 24, 0, 8);
 /* Init function */
 BlendFunction gst_video_mixer_blend_argb;
 BlendFunction gst_video_mixer_blend_bgra;
-BlendFunction gst_video_mixer_overlay_argb;
-BlendFunction gst_video_mixer_overlay_bgra;
 /* AYUV/ABGR is equal to ARGB, RGBA is equal to BGRA */
 BlendFunction gst_video_mixer_blend_y444;
 BlendFunction gst_video_mixer_blend_y42b;
@@ -726,8 +724,6 @@ gst_video_mixer_init_blend (void)
 
   gst_video_mixer_blend_argb = blend_argb;
   gst_video_mixer_blend_bgra = blend_bgra;
-  gst_video_mixer_overlay_argb = overlay_argb;
-  gst_video_mixer_overlay_bgra = overlay_bgra;
   gst_video_mixer_blend_i420 = blend_i420;
   gst_video_mixer_blend_y444 = blend_y444;
   gst_video_mixer_blend_y42b = blend_y42b;
